#
# spec file for package libopenraw
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libopenraw
Version:        0.3.1
Release:        bp155.1.47
Summary:        A library to decode digital camera RAW files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://libopenraw.freedesktop.org/
Source0:        http://libopenraw.freedesktop.org/download/%{name}-%{version}.tar.bz2
Source1:        http://libopenraw.freedesktop.org/download/%{name}-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
# cd lib/mp4 && cargo vendor -s Cargo.toml -s mp4parse/Cargo.toml -s mp4parse_capi/Cargo.toml && tar cf vendor.tar.xz vendor
Source3:        vendor.tar.xz
Source99:       baselibs.conf
BuildRequires:  autoconf >= 2.69
BuildRequires:  cargo
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  rust
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.21
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.5.0
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_test-devel >= 1.60.0
%else
BuildRequires:  boost-devel >= 1.60.0
%endif

%description
libopenraw is a library that aim at decoding digital camera RAW files.

%package -n libopenraw9
Summary:        A library to decode digital camera RAW files
Group:          System/Libraries
# libopenraw.so.0, version 0.3.1, was wrongly packaged in libopenraw1
Conflicts:      libopenraw1 >= 0.3

%description -n libopenraw9
libopenraw is a library that aim at decoding digital camera RAW files.

%package -n gdk-pixbuf-loader-libopenraw
Summary:        gdk-pixbuf loader for libopenraw
Group:          System/Libraries
Supplements:    packageand(libopenraw9:gdk-pixbuf)
%{gdk_pixbuf_loader_requires}

%description -n gdk-pixbuf-loader-libopenraw
libopenraw is a library that aim at decoding digital camera RAW files.

This package provides a libopenraw-based gdk-pixbuf loader.

%package -n libopenraw-devel
Summary:        A library to decode digital camera RAW files
Group:          Development/Libraries/C and C++
#include gdk-pixbuf/gdk-pixbuf.h
Requires:       gdk-pixbuf-devel
Requires:       libopenraw9 = %{version}-%{release}

%description  -n libopenraw-devel
libopenraw is a library that aim at decoding digital camera RAW files.

%prep
%autosetup -a3
mv vendor lib/mp4/
cd lib/mp4
sed -i 's/byteorder = "1.2.1"/byteorder = "1.2.2"/' mp4parse/Cargo.toml
mkdir .cargo
cat <<EOF >> .cargo/config.toml
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"
EOF

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n libopenraw9 -p /sbin/ldconfig
%postun -n libopenraw9 -p /sbin/ldconfig

%post -n gdk-pixbuf-loader-libopenraw
%{gdk_pixbuf_loader_post}

%postun -n gdk-pixbuf-loader-libopenraw
%{gdk_pixbuf_loader_postun}

%files -n libopenraw9
%license COPYING
%{_libdir}/*.so.*

%files -n gdk-pixbuf-loader-libopenraw
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libopenraw_pixbuf.so

%files -n libopenraw-devel
%doc README TODO ChangeLog
%{_libdir}/*.so
%dir %{_includedir}/libopenraw-0.3
%{_includedir}/libopenraw-0.3/*
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Move documentation to where it's used: with the -devel subpackage.
- Update descriptions, RPM groups
- Trim --with-pic (only has effects for static libs)
- Repair a bit more of libopenraw1->9
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Rename libopenraw1 subpackage to libopenraw9, making the package
  name the actual library provided.
- Make libopenraw9 conflict with libopenraw1 >= 0.3 to ease the
  upgrade path from the wrongly named package.
* Wed Apr 20 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 0.3.1:
  + Changes:
  * API: some camera ID have been renamed or value changed.
  * API: or_rawdata_get_roi() renamed to or_rawdata_get_active_area().
  * API: cfa_pattern renamed to mosaicinfo.
  * API: Added or_ifd_release(), or_ifd_get_name() and or_ifd_get_type().
  * API: The ORIfdDirRef returned by or_rawfile_get_ifd() must
    be released.
  * API: or_rawfile_get_ifd() support more IFD types.
  * API: or_ifd_index is replaced by or_ifd_dir_type. OR_IFD_MAKERNOTE is replaced
    by OR_IFD_MNOTE, OR_IFD_CFA is replaced by OR_IFD_RAW.
  * API: or_iterator*() to iterate through the metadata tags.
  * API: Added or_metavalue_get_count().
  * Fix getting MakerNotes for Pentax, Panasonic.
  * Get the Panasonic Exif thumbnail.
  * Added tool `exifdump`.
  + Lots of new cameras added and bugs fixed. See the following link for a complete
    list: https://gitlab.freedesktop.org/libopenraw/libopenraw/-/blob/master/NEWS
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.1.3:
  + Add support for lots and lots of new cameras.
  + Rename .pc to libopenraw-0.1.pc.
- Drop patches fixed upstream:
  + libopenraw-orf-thumbnail.patch.
  + openraw-noansiflag.patch.
- Following the above, drop autoconf, automake and libtool
  BuildRequires and autoreconf usage.
- Stop exporting no longer needed CXXFLAGS.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Fri Jul 15 2016 alarrosa@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue Jun 16 2015 mpluskal@suse.com
- Add gpg signature
- Cleanup spec file with spec-cleaner
- Add missing dependency on curl
* Thu May 10 2012 crrodriguez@opensuse.org
- Run make check
- Do not use gcc -ansi flag
- Ensure all C files include "config.h"
* Fri Feb 24 2012 crrodriguez@opensuse.org
- Build C++ code with -fvisibility-inlines-hidden shrinks
  the exported symbol table from 1844 to 1476 entries.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 0.0.9:
  + New features:
  - New demo ppmload to create a ppm out of the demosaicized
    image.
  - Support (partially) PEF from Pentax K20D.
  - Support for Olympus ORF big-endian files and "RS" (12-bits).
    Added E-10, E-P1, E-620, SP350, SP500, SP510 and SP550.
  - Support for Canon G10, G11, 7D, 1DMarkIV, 5DMarkII, 500D,
    550D, 60D and 1000D.
  - Support for Canon 50D (fdo#30846).
  - Support for Nikon D3000.
  - Support for Sony A-550.
  - Support for Leica X1 DNG.
  - Support for Ricoh GRX DNG.
  + Bug fixes:
  - API: or_rawfile_get_rendered_image() returns a
    ORBitmapDataRef with the correct dimensions.
  - Check for get_current_dir_name() (fdo#24088)
  - Don't crash when the files can't be written in the testsuite
    bootstrap.
  - Detect that ORF file are compressed if they are (fdo#26618).
  - Skip compressed CFA when rendering the image (fdo#25464).
  - Accept YCbCr when the compression is JPEG. The K10D DNG
    should now have the large size preview.
  - Install the GdkPixbuf in the right place (fdo#29208).
  + Internal changes:
  - Rename debug.{h,cpp} to trace.{h,cpp}
  - Fixed the case on several class names.
- Drop libopenraw-gdk-pixbuf-loaders-path.patch: fixed upstream.
- Drop libopenraw-detect-compressed-otf.patch: fixed upstream.
- Rebase libopenraw-orf-thumbnail.patch.
* Mon Sep  5 2011 glin@suse.com
- Merge upstream patch libopenraw-detect-compressed-otf.patch to
  avoid segfault while loading Olympus raw files (.orf)
  bnc#561232, fdo#26618
- Rebase and merge upstream patch libopenraw-orf-thumbnail.patch to
  decompress otf bnc#699678
- Add autoreconf to %%build to refresh Makefiles
- Remove the invalid link in Source0
* Mon Oct 11 2010 vuntz@opensuse.org
- Add missing Requires for gdk-pixbuf-query-loaders to
  gdk-pixbuf-loader-libopenraw in baselibs.conf.
* Wed Jul 21 2010 vuntz@opensuse.org
- Change gtk2-devel and libxml2-devel BuildRequires to
  pkgconfig(gdk-pixbuf-2.0) and pkgconfig(libxml-2.0).
- Add explicit pkgconfig(glib-2.0) BuildRequires.
- Add libopenraw-gdk-pixbuf-loaders-path.patch to have the
  gdk-pixbuf loader installed where it should with the new
  gdk-pixbuf library. Patch was committed upstream.
- Note that we require gdk-pixbuf >= 2.21 for the build because of
  the patch.
- Split the gdk-pixbuf loader in a gdk-pixbuf-loader-libopenraw
  subpackage (that gets installed automatically when gdk-pixbuf is
  installed thanks to a Supplements).
- Change gtk2-devel Requires in devel package to gdk-pixbuf-devel.
- Add baselibs.conf, so that the pixbuf loader can work with 32bit
  version of gdk-pixbuf.
* Fri May 22 2009 vuntz@novell.com
- Update to version 0.0.8:
  + includes missing for gcc 4.4
- Changes from version 0.0.7:
  + fix some warnings in the test and demo programs.
  + fix a huge memory leak (fdo#21435)
- Changes from version 0.0.6:
  + LICENSE change to LGPLv3+
  + BUG: cfa output should write the data in PGM as big endian.
  + BUG: added missing includes breaking on gcc 4.3 and other
    platforms. (Closes bug fdo#18243).
  + BUG: better handling of Canon CR2 "slices" to fix crasher
    with Canon 450D/Digital Rebel XSi files (and possibly others).
  + NEW: API or_rawfile_new_from_memory() to load a Raw file from
    a memory buffer.
  + NEW: API or_rawfile_get_typeid() and the associated consts.
  + NEW: API or_rawdata_get_minmax()
  + NEW: API or_get_file_extensions()
  + NEW: API or_rawfile_get_rendered_image() to get a rendered
    image.
  + NEW: API or_bitmapdata_*()
  + NEW: GdkPixbuf loader.
  + NEW: Decompress NEF files.
  + NEW: Python bindings.
  + NEW: testsuite can be overridden with an override file.
  + NEW: testsuite can be bootstrapped to download its files off
    the internet.
  + NEW: add shave to the build system for saner output.
  + TODO: apply the coefficients.
- Drop libopenraw-gcc44.patch: fixed upstream.
- Use makeinstall.
- Package new GdkPixbuf loader.
* Wed Feb 25 2009 coolo@suse.de
- update to compile against gcc 4.4
* Mon Jan  5 2009 crrodriguez@suse.de
- exclude static libraries
- fix -devel package dependencies
* Fri Nov 21 2008 hfiguiere@suse.de
- Disable make check in the mean time until the boost issue is
  solved.
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Thu Apr  3 2008 hfiguiere@suse.de
- Initial checkin
